Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(105)

Unified Diff: chrome/browser/ui/views/payments/credit_card_editor_view_controller.cc

Issue 2910153002: Remove views::Label::SetDisabledColor(). Replace with typography colors. (Closed)
Patch Set: respond to comments Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/credit_card_editor_view_controller.cc
diff --git a/chrome/browser/ui/views/payments/credit_card_editor_view_controller.cc b/chrome/browser/ui/views/payments/credit_card_editor_view_controller.cc
index 0068ad31e81f79f8d18e854686b9fbab46418ec7..bfadbb719486afc2859b1270649a8d9b81bdb737 100644
--- a/chrome/browser/ui/views/payments/credit_card_editor_view_controller.cc
+++ b/chrome/browser/ui/views/payments/credit_card_editor_view_controller.cc
@@ -204,13 +204,10 @@ CreditCardEditorViewController::CreateHeaderView() {
views::BoxLayout::CROSS_AXIS_ALIGNMENT_START);
view->SetLayoutManager(layout);
- // "Cards accepted" label is "disabled" grey.
- std::unique_ptr<views::Label> label = base::MakeUnique<views::Label>(
- l10n_util::GetStringUTF16(IDS_PAYMENTS_ACCEPTED_CARDS_LABEL));
- label->SetDisabledColor(label->GetNativeTheme()->GetSystemColor(
- ui::NativeTheme::kColorId_LabelDisabledColor));
- label->SetEnabled(false);
- view->AddChildView(label.release());
+ // "Cards accepted" label is "hint" grey.
+ view->AddChildView(CreateHintLabel(l10n_util::GetStringUTF16(
+ IDS_PAYMENTS_ACCEPTED_CARDS_LABEL))
+ .release());
// 8dp padding is required between icons.
constexpr int kPaddingBetweenCardIcons = 8;

Powered by Google App Engine
This is Rietveld 408576698